# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AgentChatMessagePartType(Enum):
    TEXT = "text"
    DATA_ATTACHMENTS = "data-attachments"
    DYNAMIC_TOOL = "dynamic-tool"
